territory = {
 'aery': 28,
 'aetherochemical research facility': 0,
 'akh afah amphitheatre': 46,
 'ala mhigo': 0,
 'alexander': 0,
 'amdapor keep': 28,
 'antitower': 0,
 'aquapolis': 0,
 'arm of the father': 0,
 'arm of the son': 0,
 'astragalos': 0,
 'aurum vale': 0,
 'azim steppe': 85,
 'azys lla': 54,
 "baelsar's wall": 40,
 "bardam's mettle": 0,
 'battlehall': 0,
 'binding coil of bahamut': 0,
 'blessed treasury': 77,
 'blue sky': 0,
 'bokairo inn': 82,
 'bowl of embers': 25,
 "brayflox's longstop": 0,
 'breath of the creator': 0,
 'burden of the father': 0,
 'burden of the son': 0,
 'burn': 0,
 'burning heart': 44,
 'carteneau flats: borderland ruins': 0,
 'castrum abania': 0,
 'castrum fluminis': 0,
 'castrum meridianum': 0,
 'central azys lla': 0,
 'central decks': 0,
 'central shroud': 3,
 'central thanalan': 10,
 'chocobo square': 0,
 'chrysalis': 0,
 'churning mists': 52,
 'cloud nine': 0,
 'coerthas central highlands': 21,
 'coerthas western highlands': 49,
 'command room': 14,
 'company workshop - mist': 0,
 'company workshop - shirogane': 0,
 'company workshop - the goblet': 0,
 'company workshop - the lavender beds': 0,
 'containment bay p1t6': 69,
 'containment bay s1t7': 66,
 'containment bay z1t9': 75,
 'copperbell mines': 0,
 'crystal tower training grounds': 90,
 'cuff of the father': 0,
 'cuff of the son': 0,
 "cutter's cry": 0,
 "dalamud's shadow": 0,
 'deltascape v1.0': 88,
 'deltascape v2.0': 88,
 'deltascape v3.0': 88,
 'deltascape v4.0': 88,
 'diadem': 60,
 'doma castle': 0,
 'doman enclave': 84,
 'dravanian forelands': 50,
 'dravanian hinterlands': 51,
 'drowned city of skalla': 0,
 'dun scaith': 58,
 'dusk vigil': 42,
 'dzemael darkhold': 0,
 'east shroud': 4,
 'eastern la noscea': 18,
 'eastern thanalan': 11,
 'eighteenth floor': 0,
 'emanation': 87,
 'eorzean alliance headquarters': 0,
 'eorzean subterrane': 0,
 'eureka anemos': 91,
 'eureka hydatos': 100,
 'eureka pagos': 94,
 'eureka pyros': 96,
 'eyes of the creator': 0,
 "fall of belah'dia": 0,
 'feasting grounds': 65,
 'fields of glory': 67,
 'first altar of djanan qhat': 0,
 'fist of the father': 0,
 'fist of the son': 0,
 'flame barracks': 0,
 'fold': 0,
 'fortemps manor': 0,
 'foundation': 47,
 'fractal continuum': 0,
 'fringes': 79,
 "frondale's ward for friendless foundlings": 0,
 'ghimlyt dark': 0,
 'goblet': 33,
 'gold saucer': 0,
 'great gubal library': 0,
 'great hunt': 0,
 'griffin crossing': 0,
 'halatali': 0,
 'hall of summoning': 0,
 'hall of the bestiarii': 0,
 'haukke manor': 0,
 'haunted manor': 0,
 'heart of the creator': 0,
 'heart of the sworn': 0,
 'heaven-on-high': 0,
 "hells' kier": 98,
 "hells' lid": 0,
 'hidden gorge': 0,
 'holocharts': 0,
 'hourglass': 0,
 'house of the fierce': 84,
 'howling eye': 26,
 'hullbreaker isle': 0,
 'ic-04 main bridge': 0,
 'ic-06 central decks': 0,
 'ic-06 main bridge': 0,
 'ic-06 regeneration grid': 0,
 'idyllshire': 55,
 'intercessory': 0,
 'interdimensional rift': 92,
 'jade stoa': 93,
 'keeper of the lake': 74,
 'kienkan': 0,
 'kobai goten apartment': 0,
 'kobai goten apartment lobby': 0,
 'kugane': 82,
 'kugane castle': 0,
 'kugane ohashi': 0,
 'labyrinth of the ancients': 0,
 'lavender beds': 34,
 "leofard's chambers": 0,
 'lichenweed': 73,
 'lightfeather proving grounds': 0,
 'lily hills apartment': 0,
 'lily hills apartment lobby': 0,
 'limitless blue': 28,
 'limsa lominsa': 0,
 'limsa lominsa lower decks': 15,
 'limsa lominsa upper decks': 14,
 'lochs': 81,
 'lost canals of uznair': 0,
 'lost city of amdapor': 40,
 'lotus stand': 0,
 'lower aetheroacoustic exploratory site': 0,
 'lower la noscea': 17,
 'maelstrom barracks': 0,
 'main bridge': 0,
 'manderville tables': 0,
 "matoya's cave": 0,
 'middle la noscea': 16,
 'misery': 36,
 'mist': 14,
 'mizzenmast inn': 0,
 'mor dhona': 22,
 'mordion gaol': 0,
 'navel': 23,
 'neverreap': 0,
 'new gridania': 1,
 'north shroud': 6,
 'northern thanalan': 13,
 'old gridania': 2,
 'omega control': 0,
 'orbonne monastery': 0,
 'outer coil': 28,
 'outer la noscea': 24,
 'palace of the dead': 0,
 'parrock': 0,
 'peaks': 80,
 'pharos sirius': 28,
 'pillars': 48,
 'porta decumana': 31,
 'praetorium': 0,
 'prima vista bridge': 0,
 'prima vista tiring room': 0,
 'private chambers - mist': 0,
 'private chambers - shirogane': 0,
 'private chambers - the goblet': 0,
 'private chambers - the lavender beds': 0,
 'private cottage - mist': 0,
 'private cottage - shirogane': 0,
 'private cottage - the goblet': 0,
 'private cottage - the lavender beds': 0,
 'private house - mist': 0,
 'private house - shirogane': 0,
 'private house - the goblet': 0,
 'private house - the lavender beds': 0,
 'private mansion - mist': 0,
 'private mansion - shirogane': 0,
 'private mansion - the goblet': 0,
 'private mansion - the lavender beds': 0,
 'psiscape v1.0': 92,
 'psiscape v2.0': 92,
 'ragnarok': 0,
 'ragnarok central core': 0,
 'ragnarok drive cylinder': 0,
 'ragnarok main bridge': 0,
 'reisen temple': 0,
 'reisen temple road': 0,
 'resonatorium': 0,
 "rhalgr's reach": 78,
 'rhotano sea': 0,
 'ridorana cataract': 0,
 'ridorana lighthouse': 0,
 'rising stones': 0,
 'roost': 0,
 'royal airship landing': 76,
 'royal city of rabanastre': 0,
 'royal menagerie': 0,
 'royal palace': 0,
 'ruby bazaar offices': 0,
 'ruby sea': 83,
 'ruling chamber': 0,
 'sacrificial chamber': 0,
 "saint endalim's scholasticate": 0,
 "saint mocianne's arboretum": 0,
 'sanctum of the twelve': 0,
 'sastasha': 0,
 'sea of clouds': 53,
 'seal rock': 59,
 'seat of the first bow': 0,
 'seat of the lord commander': 0,
 'shifting altars of uznair': 0,
 'shirogane': 82,
 'shisui of the violet tides': 0,
 'sigmascape v1.0': 92,
 'sigmascape v2.0': 92,
 'sigmascape v3.0': 92,
 'sigmascape v4.0': 92,
 'singularity reactor': 56,
 'sirensong sea': 36,
 'snowcloak': 42,
 'sohm al': 0,
 'sohr khai': 0,
 'soul of the creator': 0,
 'south shroud': 5,
 'southern thanalan': 12,
 'steps of faith': 28,
 'stone vigil': 27,
 'striking tree': 43,
 "sultana's breath apartment": 0,
 "sultana's breath apartment lobby": 0,
 'sunken temple of qarn': 0,
 "swallow's compass": 0,
 'syrcus tower': 0,
 'tam-tara deepcroft': 0,
 'temple of the fist': 0,
 'thok ast thok': 57,
 'thornmarch': 30,
 'thousand maws of toto-rak': 0,
 'topmast apartment': 0,
 'topmast apartment lobby': 0,
 'transparency': 76,
 'twin adder barracks': 0,
 "ul'dah - steps of nald": 7,
 "ul'dah - steps of thal": 8,
 'ultimacy': 26,
 'upper aetheroacoustic exploratory site': 0,
 'upper la noscea': 20,
 'vault': 0,
 'void ark': 37,
 'waking sands': 0,
 "wanderer's palace": 0,
 'weeping city of mhach': 0,
 'weeping saint': 21,
 'western la noscea': 19,
 'western thanalan': 9,
 'whorleater': 38,
 "wolves' den pier": 29,
 'world of darkness': 0,
 'wreath of snakes': 99,
 'xelphatol': 40,
 'yanxia': 84
}
